==> qtmobilehotspot_0.2.tar.gz: qtmobilehotspot-0.2/qtMobileHotspot/src/mobilehotspotconfiguration.cpp <==
#include <QtCore/QObject>
#include <QtCore/QString>
#include <gq/gconfitem.h>
#include "mobilehotspotconfiguration.h"

const QString MobileHotspotConfiguration::ENCRYPTION_NONE = QString("None");
const QString MobileHotspotConfiguration::ENCRYPTION_WEP = QString("WEP");
const QString MobileHotspotConfiguration::INTERFACE_USB = QString("usb0");
const QString MobileHotspotConfiguration::INTERFACE_WLAN = QString("wlan0");


MobileHotspotConfiguration::MobileHotspotConfiguration(QObject *parent)
	:	QObject(parent){
	internet = true;
}

MobileHotspotConfiguration::~MobileHotspotConfiguration(){
}

void MobileHotspotConfiguration::load(){
	GConfItem *item;

	item = new GConfItem(GCONF_APNAME);
	apname = item->value("N900 Hotspot").toString();
	delete item;

	item = new GConfItem(GCONF_ENCRYPTION);
	encryption = item->value(ENCRYPTION_NONE).toString();
	delete item;

	item = new GConfItem(GCONF_KEY);
	key = item->value("0000000000000").toString();
	delete item;

	item = new GConfItem(GCONF_INTERFACE);
	interface = item->value(INTERFACE_WLAN).toString();
	delete item;

	item = new GConfItem(GCONF_APN);
	apn = item->value("").toString();
	delete item;

	item = new GConfItem(GCONF_APID);
	apid = item->value("").toString();
	delete item;

	item = new GConfItem(GCONF_NETWORK);
	network = item->value("192.168.254.").toString();
	delete item;

	item = new GConfItem(GCONF_INTERNET);
	internet = item->value("true").toString() == "true";
	delete item;

	item = new GConfItem(GCONF_2G3G);
	QString enf = item->value("ignore").toString();
	if(enf == "2g")
		enforcement2g3g = ENFORCE_2G;
	else if(enf == "3g")
		enforcement2g3g = ENFORCE_3G;
	else if(enf == "2g3g")
		enforcement2g3g = ENFORCE_2G3G;
	else
		enforcement2g3g = IGNORE;
	delete item;
}

void MobileHotspotConfiguration::save(){
	GConfItem *item;

	item = new GConfItem(GCONF_APNAME);
	item->set(apname);
	delete item;

	item = new GConfItem(GCONF_ENCRYPTION);
	item->set(encryption);
	delete item;

	item = new GConfItem(GCONF_KEY);
	item->set(key);
	delete item;

	item = new GConfItem(GCONF_INTERFACE);
	item->set(interface);
	delete item;

	item = new GConfItem(GCONF_APN);
	item->set(apn);
	delete item;

	item = new GConfItem(GCONF_APID);
	item->set(apid);
	delete item;

	item = new GConfItem(GCONF_NETWORK);
	item->set(network);
	delete item;

	item = new GConfItem(GCONF_INTERNET);
	item->set(internet ? "true" : "false");
	delete item;

	item = new GConfItem(GCONF_2G3G);
	if(enforcement2g3g == ENFORCE_2G)
		item->set("2g");
	else if(enforcement2g3g == ENFORCE_3G)
		item->set("3g");
	else if(enforcement2g3g == ENFORCE_2G3G)
		item->set("2g3g");
	else
		item->set("ignore");
	delete item;
}

==> qtmobilehotspot_0.3.tar.gz: qtmobilehotspot-0.3/qtMobileHotspot/src/mobilehotspotconfiguration.cpp <==
#include <QtCore/QObject>
#include <QtCore/QString>
#include <gq/gconfitem.h>
#include "dbushelper.h"
#include "apnhelper.h"
#include "mobilehotspotconfiguration.h"

const QString MobileHotspotConfiguration::ENCRYPTION_NONE = QString("None");
const QString MobileHotspotConfiguration::ENCRYPTION_WEP = QString("WEP");
const QString MobileHotspotConfiguration::INTERFACE_GPRS = QString("gprs0");
const QString MobileHotspotConfiguration::INTERFACE_USB = QString("usb0");
const QString MobileHotspotConfiguration::INTERFACE_WLAN = QString("wlan0");


MobileHotspotConfiguration::MobileHotspotConfiguration(QObject *parent)
	:	QObject(parent){
	internetEnabled = true;
}

MobileHotspotConfiguration::~MobileHotspotConfiguration(){
}

void MobileHotspotConfiguration::load(){
	GConfItem *item;

	item = new GConfItem(GCONF_APNAME);
	hotspotName = item->value("N900 Hotspot").toString();
	delete item;

	item = new GConfItem(GCONF_ENCRYPTION);
	encryptionType = item->value(ENCRYPTION_NONE).toString();
	delete item;

	item = new GConfItem(GCONF_KEY);
	encryptionKey = item->value("0000000000000").toString();
	delete item;

	item = new GConfItem(GCONF_POWER);
	disablePowerSaving = item->value("false").toString() == "true";
	delete item;

	item = new GConfItem(GCONF_INTERFACE);
	lanInterface = item->value(INTERFACE_WLAN).toString();
	delete item;

	item = new GConfItem(GCONF_APN);
	internetAPName = item->value("").toString();
	delete item;

	item = new GConfItem(GCONF_APTYPE);
	internetAPType = item->value("").toString();
	delete item;

	item = new GConfItem(GCONF_APID);
	internetAPID = item->value("").toString();
	delete item;

	item = new GConfItem(GCONF_NETWORK);
	lanNetwork = item->value("192.168.254.").toString();
	delete item;

	item = new GConfItem(GCONF_INTERNET);
	internetEnabled = item->value("true").toString() == "true";
	delete item;

	item = new GConfItem(GCONF_2G3G);
	QString enf = item->value("ignore").toString();
	if(enf == "2g")
		enforcement2g3g = ENFORCE_2G;
	else if(enf == "3g")
		enforcement2g3g = ENFORCE_3G;
	else if(enf == "2g3g")
		enforcement2g3g = ENFORCE_2G3G;
	else
		enforcement2g3g = IGNORE;
	delete item;
}

void MobileHotspotConfiguration::save(){
	GConfItem *item;

	item = new GConfItem(GCONF_APNAME);
	item->set(hotspotName);
	delete item;

	item = new GConfItem(GCONF_ENCRYPTION);
	item->set(encryptionType);
	delete item;

	item = new GConfItem(GCONF_KEY);
	item->set(encryptionKey);
	delete item;

	item = new GConfItem(GCONF_POWER);
	item->set(disablePowerSaving ? "true" : "false");
	delete item;

	item = new GConfItem(GCONF_INTERFACE);
	item->set(lanInterface);
	delete item;

	item = new GConfItem(GCONF_APN);
	item->set(internetAPName);
	delete item;

	item = new GConfItem(GCONF_APTYPE);
	item->set(internetAPType);
	delete item;

	item = new GConfItem(GCONF_APID);
	item->set(internetAPID);
	delete item;

	item = new GConfItem(GCONF_NETWORK);
	item->set(lanNetwork);
	delete item;

	item = new GConfItem(GCONF_INTERNET);
	item->set(internetEnabled ? "true" : "false");
	delete item;

	item = new GConfItem(GCONF_2G3G);
	if(enforcement2g3g == ENFORCE_2G)
		item->set("2g");
	else if(enforcement2g3g == ENFORCE_3G)
		item->set("3g");
	else if(enforcement2g3g == ENFORCE_2G3G)
		item->set("2g3g");
	else
		item->set("ignore");
	delete item;
}

QString MobileHotspotConfiguration::internetInterface() const{
	if(internetAPType == GCONF_APN_TYPE_INFRA || internetAPType == GCONF_APN_TYPE_ADHOC)
		return INTERFACE_WLAN;
	else
		return INTERFACE_GPRS;
}
